==> windowmatrixd-0.1.1.tar.gz: windowmatrixd-0.1.1/network.c <==
#include <sys/socket.h>

#include <netinet/in.h>

#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include "config.h"
#include "network.h"


/* get_frame
This function reads a frame from a given socket, which must be bound to an
address. It blocks the program until a new frame arrives, unless the socket is
nonblocking. The function returns 1 for success and saves the frame in the
given buffer. On failure, the function returns 0, the buffer might then contain
garbage */

inline char
get_frame (int sock, frame_t *  frame)
{
  int size;

  if (((size = recvfrom (sock, (void *) frame, sizeof (*frame),               \
			 0, NULL, 0)) == sizeof (frame_t)))
    {
      frame->frame_magic = ntohl (frame->frame_magic);
      frame->frame_width = ntohs (frame->frame_width);
      frame->frame_height = ntohs (frame->frame_height);

      if ((frame->frame_magic == MAGIC) || (frame->frame_width == WIDTH) ||   \
	  (frame->frame_height == HEIGHT))
	{
	  frame->frame_count = ntohl (frame->frame_count);
	  return ((char) 1);
	}
    }
  fprintf (stderr, "Incorrect frame-header:\n"                                \
	   "Magic:  0x%08X, expecting 0x%08X\n"                               \
	   "Width:  0x%04hX, expecting 0x%04hX\n"                             \
	   "Height: 0x%04hX, expecting 0x%04hX\n"                             \
	   "Size:   %i, expecting %lu\n\n",                                   \
	   frame->frame_magic, MAGIC, frame->frame_width,                     \
	   WIDTH, frame->frame_height, HEIGHT, size,                          \
	   (unsigned long) sizeof (*frame));
  return ((char) 0);
}


/* setup_socket
This function creates the socket we are going to use and binds it to a port. It
returns -1 on failure and the filedescriptor on success. setup_socket should be
called after setting up the output devices as the socket will be able to
receive messages right afterwards */

char
setup_socket (int *  sock)
{
  int                i;
  struct sockaddr_in addr;

  if ((*sock = socket (PF_INET, SOCK_DGRAM, IPPROTO_UDP)) != -1)
    {
      i = 1;
      if ((setsockopt (*sock, SOL_SOCKET, SO_REUSEADDR, &i, sizeof (i))) != -1)
	{
	  addr.sin_family      = PF_INET;
	  addr.sin_addr.s_addr = INADDR_ANY;
	  addr.sin_port        = htons (PORT);
	  if ((bind (*sock, (struct sockaddr *) &addr, sizeof (addr))) != -1)
	    {
	      return ((char) 1);
	    }
	}
      close (*sock);
    }
  return ((char) 0);
}


/* close_socket
This function closes the socket */

void
close_socket (int * sock)
{
  close (*sock);
}

==> windowmatrixd-0.1.2.tar.gz: windowmatrixd-0.1.2/network.c <==
#include <sys/socket.h>

#include <netinet/in.h>

#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include "config.h"
#include "network.h"


/* setup_socket
This function creates the socket we are going to use and binds it to a port. It
returns -1 on failure and the filedescriptor on success. setup_socket should be
called after setting up the output devices as the socket will be able to
receive messages right afterwards */

char
setup_socket (int *  sock, struct sockaddr_in * addr)
{
  int                i;

  if ((*sock = socket (PF_INET, SOCK_DGRAM, IPPROTO_UDP)) != -1)
    {
      i = 1;
      if ((setsockopt (*sock, SOL_SOCKET, SO_REUSEADDR, &i, sizeof (i))) != -1)
	{
	  addr->sin_family      = PF_INET;
	  if ((bind (*sock, (struct sockaddr *) addr, sizeof (*addr))) != -1)
	    {
	      return ((char) 1);
	    }
	}
      close (*sock);
    }
  return ((char) 0);
}


/* close_socket
This function closes the socket */

void
close_socket (int * sock)
{
  close (*sock);
}


/* get_frame
This function reads a frame from a given socket, which must be bound to an
address. It blocks the program until a new frame arrives, unless the socket is
nonblocking. The function returns 1 for success and saves the frame in the
given buffer. On failure, the function returns 0, the buffer might then contain
garbage */

inline char
get_frame (const int sock, struct sockaddr_in * addr, frame_t * frame)
{
  int       size;
  socklen_t fromlen;

  fromlen = sizeof (*addr);

  if (((size = recvfrom (sock, (void *) frame, sizeof (*frame),               \
			 0, (struct sockaddr *) addr, &fromlen)) ==           \
       sizeof (frame_t)))
    {
      frame->frame_magic = ntohl (frame->frame_magic);
      frame->frame_width = ntohs (frame->frame_width);
      frame->frame_height = ntohs (frame->frame_height);

      if ((frame->frame_magic == MAGIC) || (frame->frame_width == WIDTH) ||   \
	  (frame->frame_height == HEIGHT))
	{
	  frame->frame_count = ntohl (frame->frame_count);
	  return ((char) 1);
	}
    }
  fprintf (stderr, "Incorrect frame-header:\n"                                \
	   "Magic:  0x%08X, expecting 0x%08X\n"                               \
	   "Width:  0x%04hX, expecting 0x%04hX\n"                             \
	   "Height: 0x%04hX, expecting 0x%04hX\n"                             \
	   "Size:   %i, expecting %lu\n\n",                                   \
	   frame->frame_magic, MAGIC, frame->frame_width,                     \
	   WIDTH, frame->frame_height, HEIGHT, size,                          \
	   (unsigned long) sizeof (*frame));
  return ((char) 0);
}
